@@ -1,8 +1,8 @@
-from proto_formatter.proto_structures import Comment
-from proto_formatter.comment import CommentParser
-from proto_formatter.constant import Constant
-from proto_formatter.proto_structures import Position
-from proto_formatter.util import remove_prefix, remove_suffix
+from .proto_structures import Comment
+from .comment import CommentParser
+from .constant import Constant
+from .proto_structures import Position
+from .util import remove_prefix, remove_suffix
 
 
 class Detector(Constant):
@@ -116,7 +116,7 @@ class Detector(Constant):
                 return False
 
         if line.count(self.MULTIPLE_COMENT_START_SYMBOL) > 0:
-            if ine.index(self.SEMICOLON) > ine.index(self.MULTIPLE_COMENT_START_SYMBOL):
+            if line.index(self.SEMICOLON) > line.index(self.MULTIPLE_COMENT_START_SYMBOL):
                 return False
 
         if self._is_service_element_line(line):
